@@ -1,6 +1,6 @@
 /*
  *
- *   Copyright (C) 2012-2015 by C.H. Huang
+ *   Copyright (C) 2012-2016 by C.H. Huang
  *   plushuang.tw@gmail.com
  *
  *  This library is free software; you can redistribute it and/or
@@ -63,6 +63,7 @@ typedef struct  UgetApp          UgetApp;
 	UgRegistry      plugins;        \
 	UgetPluginInfo* plugin_default; \
 	UgetTask        task;           \
+	UgArrayPtr      nodes;          \
 	void*           uri_hash;       \
 	char*           config_dir;     \
 	int             n_error;        \
@@ -82,6 +83,7 @@ struct UgetApp
 //	UgRegistry      plugins;
 //	UgetPluginInfo* plugin;
 //	UgetTask        task;
+//	UgArrayPtr      nodes;
 //	void*           uri_hash;
 //	char*           config_dir;
 //	int             n_error;     // these n_xxxx increase by uget_app_grow()
@@ -108,14 +110,14 @@ void  uget_app_add_category (UgetApp* app, UgetNode* cnode, int save_file);
 int   uget_app_move_category (UgetApp* app, UgetNode* cnode, UgetNode* position);
 void  uget_app_delete_category (UgetApp* app, UgetNode* cnode);
 void  uget_app_stop_category (UgetApp* app, UgetNode* cnode);
-UgetNode* uget_app_match_category (UgetApp* app, UgUri* uuri);
+UgetNode* uget_app_match_category (UgetApp* app, UgUri* uuri, const char* file);
 
 // download functions: return TRUE or FALSE
 int   uget_app_add_download_uri (UgetApp* app, const char* uri, UgetNode* cnode, int apply);
 int   uget_app_add_download (UgetApp* app, UgetNode* dnode, UgetNode* cnode, int apply);
 int   uget_app_move_download (UgetApp* app, UgetNode* dnode, UgetNode* dnode_position);
 int   uget_app_move_download_to (UgetApp* app, UgetNode* dnode, UgetNode* cnode);
-void  uget_app_delete_download (UgetApp* app, UgetNode* dnode, int delete_file);
+int   uget_app_delete_download (UgetApp* app, UgetNode* dnode, int delete_file);
 int   uget_app_recycle_download (UgetApp* app, UgetNode* dnode);
 int   uget_app_activate_download (UgetApp* app, UgetNode* dnode);
 int   uget_app_pause_download (UgetApp* app, UgetNode* dnode);
@@ -130,14 +132,14 @@ void  uget_app_use_uri_hash (UgetApp* app);
 void  uget_app_clear_attachment (UgetApp* app);
 #endif
 
-// plugin functions
+// plug-in functions
 // uget_app_find_plugin() return TRUE or FALSE
 void  uget_app_clear_plugins (UgetApp* app);
 void  uget_app_add_plugin (UgetApp* app, const UgetPluginInfo* pinfo);
 void  uget_app_remove_plugin (UgetApp* app, const UgetPluginInfo* pinfo);
 int   uget_app_find_plugin (UgetApp* app, const char* name, const UgetPluginInfo** pinfo);
 void  uget_app_set_default_plugin (UgetApp* app, const UgetPluginInfo* pinfo);
-UgetPluginInfo*  uget_app_match_plugin (UgetApp* app, UgetNode* node);
+UgetPluginInfo*  uget_app_match_plugin (UgetApp* app, UgetNode* node, const UgetPluginInfo* exclude);
 
 // ----------------------------------------------------------------------------
 // save/load categories
