@@ -1,6 +1,6 @@
 /*
  *
- *   Copyright (C) 2012-2015 by C.H. Huang
+ *   Copyright (C) 2012-2016 by C.H. Huang
  *   plushuang.tw@gmail.com
  *
  *  This library is free software; you can redistribute it and/or
@@ -44,6 +44,8 @@
 #endif  // HAVE_LIBPWMD
 
 #define PROGRESS_COUNT_LIMIT    2
+#define LOW_SPEED_LIMIT         128
+#define LOW_SPEED_TIME          60
 
 enum SchemeType
 {
@@ -65,7 +67,7 @@ static size_t uget_curl_header_ftp0 (char *buffer, size_t size,
 static size_t uget_curl_output_none (char *buffer, size_t size,
                                      size_t nmemb, void* data);
 static size_t uget_curl_output_default (char *buffer, size_t size,
-										size_t nmemb, void* data);
+                                        size_t nmemb, void* data);
 static int    uget_curl_progress (UgetCurl* ugcurl,
                                   double  dltotal, double  dlnow,
                                   double  ultotal, double  ulnow);
@@ -122,7 +124,7 @@ static UG_THREAD_RETURN_TYPE  uget_curl_thread (UgetCurl* ugcurl)
 		ugcurl->event = NULL;
 	}
 
-	// response error
+	// HTTP response error code: 4xx Client Error, 5xx Server Error
 	if (ugcurl->response >= 400 && ugcurl->scheme_type == SCHEME_HTTP) {
 		ugcurl->state = UGET_CURL_ERROR;
 		tempstr = ug_strdup_printf ("Server response code : %ld",
@@ -130,6 +132,9 @@ static UG_THREAD_RETURN_TYPE  uget_curl_thread (UgetCurl* ugcurl)
 		ugcurl->event = uget_event_new_error (
 				UGET_EVENT_ERROR_CUSTOM, tempstr);
 		ug_free (tempstr);
+		// discard data if remote site response error.
+		ugcurl->pos = ugcurl->beg;
+		ugcurl->size[0] = 0;
 		goto exit;
 	}
 
@@ -144,10 +149,6 @@ static UG_THREAD_RETURN_TYPE  uget_curl_thread (UgetCurl* ugcurl)
 			ugcurl->state = UGET_CURL_ERROR;
 			ugcurl->event = uget_event_new_error (ugcurl->event_code, NULL);
 			ugcurl->test_ok = FALSE;
-			goto exit;
-		}
-		if (ugcurl->end > 0 && ugcurl->pos >= ugcurl->end) {
-			ugcurl->state = UGET_CURL_OK;
 			break;
 		}
 		// Don't break here
@@ -155,13 +156,17 @@ static UG_THREAD_RETURN_TYPE  uget_curl_thread (UgetCurl* ugcurl)
 	case CURLE_OUT_OF_MEMORY:
 		ugcurl->state = UGET_CURL_ERROR;
 		ugcurl->event = uget_event_new_error (
-				UGET_EVENT_ERROR_OUT_OF_RESOURCE, ugcurl->error_string);
-		goto exit;
+				UGET_EVENT_ERROR_OUT_OF_RESOURCE, NULL);
+		break;
 
-	// abort by user (exit)
+	// abort download in progress callback
 	case CURLE_ABORTED_BY_CALLBACK:
-		ugcurl->state = UGET_CURL_ABORT;
-		goto exit;
+		// segment is completed or paused by user
+		if (ugcurl->paused == FALSE)
+			ugcurl->state = UGET_CURL_OK;
+		else
+			ugcurl->state = UGET_CURL_ABORT;
+		break;
 
 	// can resume (retry)
 	case CURLE_RECV_ERROR:
@@ -203,14 +208,14 @@ static UG_THREAD_RETURN_TYPE  uget_curl_thread (UgetCurl* ugcurl)
 		ugcurl->state = UGET_CURL_ERROR;
 		ugcurl->event = uget_event_new_error (
 				UGET_EVENT_ERROR_CUSTOM, ugcurl->error_string);
-		goto exit;
+		break;
 
 	// exit
 	case CURLE_UNSUPPORTED_PROTOCOL:
 		ugcurl->state = UGET_CURL_ERROR;
 		ugcurl->event = uget_event_new_error (
 				UGET_EVENT_ERROR_UNSUPPORTED_SCHEME, ugcurl->error_string);
-		goto exit;
+		break;
 
 	// other error (exit)
 #ifdef NO_RETRY_IF_CONNECT_FAILED
@@ -225,14 +230,10 @@ static UG_THREAD_RETURN_TYPE  uget_curl_thread (UgetCurl* ugcurl)
 		ugcurl->state = UGET_CURL_ERROR;
 		ugcurl->event = uget_event_new_error (
 				UGET_EVENT_ERROR_CUSTOM, ugcurl->error_string);
-		goto exit;
+		break;
 	}
 
 exit:
-	// if user stop downloading, set state to UGET_CURL_ABORT
-	if (ugcurl->stopped == TRUE)
-		ugcurl->state = UGET_CURL_ABORT;
-
 	if (ugcurl->state == UGET_CURL_ERROR)
 		ugcurl->test_ok = FALSE;
 	ugcurl->stopped = TRUE;
@@ -248,19 +249,41 @@ void  uget_curl_run (UgetCurl* ugcurl, int joinable)
 
 	ugcurl->pos = ugcurl->beg;
 	ugcurl->state = UGET_CURL_READY;
+	ugcurl->paused = FALSE;
 	ugcurl->stopped = FALSE;    // if thread stop, this value will be TRUE.
 	ugcurl->response = 0;
 	ugcurl->event_code = 0;
 	ugcurl->progress_count = PROGRESS_COUNT_LIMIT;
-	// reset speed
+	// reset download/upload speed
 	ugcurl->speed[0] = 0;
 	ugcurl->speed[1] = 0;
+	// reset downloaded/uploaded size
+	ugcurl->size[0] = 0;
+	ugcurl->size[1] = 0;
 
 	ug_free (ugcurl->header.uri);
 	ug_free (ugcurl->header.filename);
 	ugcurl->header.uri = NULL;
 	ugcurl->header.filename = NULL;
 
+	// Others -----------------------------------------------------------------
+	curl_easy_setopt (curl, CURLOPT_NOSIGNAL, 1L);
+	curl_easy_setopt (curl, CURLOPT_FILETIME, 1L);
+	// disable peer SSL certificate verification
+	curl_easy_setopt (curl, CURLOPT_SSL_VERIFYHOST, 0L);
+	curl_easy_setopt (curl, CURLOPT_SSL_VERIFYPEER, 0L);
+	// SSL version and cipher
+//	curl_easy_setopt (curl, CURLOPT_SSLVERSION, CURL_SSLVERSION_DEFAULT);
+//	curl_easy_setopt (curl, CURLOPT_SSLVERSION, CURL_SSLVERSION_SSLv3);
+//	curl_easy_setopt (curl, CURLOPT_SSL_CIPHER_LIST, "ALL:!aNULL:!LOW:!EXPORT:!SSLv2");
+//	curl_easy_setopt (curl, CURLOPT_SSL_CIPHER_LIST, "ALL");
+//	curl_easy_setopt (curl, CURLOPT_SSL_CIPHER_LIST, "SSLv3");
+
+	// low speed limit for unstable network
+	curl_easy_setopt (curl, CURLOPT_LOW_SPEED_LIMIT, LOW_SPEED_LIMIT);
+	curl_easy_setopt (curl, CURLOPT_LOW_SPEED_TIME,  LOW_SPEED_TIME);
+
+	// resume
 	curl_easy_setopt (ugcurl->curl, CURLOPT_RESUME_FROM_LARGE,
 			(curl_off_t) ugcurl->beg);
 	// Progress  --------------------------------------------------------------
@@ -309,6 +332,15 @@ void  uget_curl_run (UgetCurl* ugcurl, int joinable)
 		}
 	}
 
+	// Speed limit ------------------------------------------------------------
+	if (ugcurl->limit_changed) {
+		curl_easy_setopt (ugcurl->curl, CURLOPT_MAX_RECV_SPEED_LARGE,
+				(curl_off_t) ugcurl->limit[0]);
+		curl_easy_setopt (ugcurl->curl, CURLOPT_MAX_SEND_SPEED_LARGE,
+				(curl_off_t) ugcurl->limit[1]);
+		ugcurl->limit_changed = FALSE;
+	}
+
 	// Output -----------------------------------------------------------------
 	curl_easy_setopt (curl, CURLOPT_NOBODY, 0L);
 	curl_easy_setopt (curl, CURLOPT_WRITEFUNCTION,
@@ -365,26 +397,10 @@ void  uget_curl_set_common (UgetCurl* ugcurl, UgetCommon* common)
 
 	curl = ugcurl->curl;
 	ugcurl->common = common;
-	// Others -----------------------------------------------------------------
-	curl_easy_setopt (curl, CURLOPT_NOSIGNAL, 1L);
-	// use with CURLINFO_FILETIME
-	curl_easy_setopt (curl, CURLOPT_FILETIME, 1L);
-	// disable peer SSL certificate verification
-	curl_easy_setopt (curl, CURLOPT_SSL_VERIFYPEER, FALSE);
-	// SSL Version and cipher
-//	curl_easy_setopt (curl, CURLOPT_SSLVERSION, CURL_SSLVERSION_DEFAULT);
-//	curl_easy_setopt (curl, CURLOPT_SSLVERSION, CURL_SSLVERSION_SSLv3);
-//	curl_easy_setopt (curl, CURLOPT_SSL_CIPHER_LIST, "ALL:!aNULL:!LOW:!EXPORT:!SSLv2");
-//	curl_easy_setopt (curl, CURLOPT_SSL_CIPHER_LIST, "ALL");
-//	curl_easy_setopt (curl, CURLOPT_SSL_CIPHER_LIST, "SSLv3");
-
-	// low speed limit for unstable network
-	curl_easy_setopt (curl, CURLOPT_LOW_SPEED_LIMIT, 128);
-	curl_easy_setopt (curl, CURLOPT_LOW_SPEED_TIME, 60);
-	curl_easy_setopt (curl, CURLOPT_CONNECTTIMEOUT, common->connect_timeout);
 
 	if (common == NULL)
 		return;
+	curl_easy_setopt (curl, CURLOPT_CONNECTTIMEOUT, common->connect_timeout);
 	curl_easy_setopt (curl, CURLOPT_URL, common->uri);
 	uget_curl_decide_scheme (ugcurl, common->uri);
 	// debug
@@ -408,59 +424,14 @@ void  uget_curl_set_common (UgetCurl* ugcurl, UgetCommon* common)
 
 void  uget_curl_set_proxy (UgetCurl* ugcurl, UgetProxy* proxy)
 {
-	CURL*    curl;
-
-	curl = ugcurl->curl;
-	if (proxy == NULL)
-		return;
-
-	// proxy type
-	switch (proxy->type) {
-	case UGET_PROXY_NONE:
-		curl_easy_setopt (curl, CURLOPT_PROXYTYPE, 0);
-		break;
-
-	default:
-	case UGET_PROXY_DEFAULT:
-	case UGET_PROXY_HTTP:
-		curl_easy_setopt (curl, CURLOPT_PROXYTYPE, CURLPROXY_HTTP);
-		break;
-
-	case UGET_PROXY_SOCKS4:
-		curl_easy_setopt (curl, CURLOPT_PROXYTYPE, CURLPROXY_SOCKS4);
-		break;
-
-	case UGET_PROXY_SOCKS5:
-		curl_easy_setopt (curl, CURLOPT_PROXYTYPE, CURLPROXY_SOCKS5);
-		break;
-
 #ifdef HAVE_LIBPWMD
-	case UGET_PROXY_PWMD:
+	if (proxy->type == UGET_PROXY_PWMD) {
 		uget_curl_set_proxy_pwmd (ugcurl, proxy);
 		return;
+	}
 #endif
-	}
 
-	curl_easy_setopt (curl, CURLOPT_PROXY, proxy->host);
-	if (proxy->port)
-		curl_easy_setopt (curl, CURLOPT_PROXYPORT, proxy->port);
-	else
-		curl_easy_setopt (curl, CURLOPT_PROXYPORT, 80);
-	// proxy user and password
-	if ((proxy->user     && proxy->user[0]) ||
-		(proxy->password && proxy->password[0]) ||
-		proxy->type == UGET_PROXY_SOCKS4 ||
-		proxy->type == UGET_PROXY_SOCKS5)
-	{
-		curl_easy_setopt (curl, CURLOPT_PROXYUSERNAME,
-				(proxy->user)     ? proxy->user     : "");
-		curl_easy_setopt (curl, CURLOPT_PROXYPASSWORD,
-				(proxy->password) ? proxy->password : "");
-	}
-	else {
-		curl_easy_setopt (curl, CURLOPT_PROXYUSERNAME, NULL);
-		curl_easy_setopt (curl, CURLOPT_PROXYPASSWORD, NULL);
-	}
+	ug_curl_set_proxy (ugcurl->curl, proxy);
 }
 
 int   uget_curl_set_http (UgetCurl* ugcurl, UgetHttp* http)
@@ -641,6 +612,54 @@ void uget_curl_decide_login (UgetCurl* ugcurl)
 	}
 }
 
+void  ug_curl_set_proxy (CURL* curl, UgetProxy* proxy)
+{
+	if (proxy == NULL)
+		return;
+
+	// proxy type
+	switch (proxy->type) {
+	case UGET_PROXY_NONE:
+		curl_easy_setopt (curl, CURLOPT_PROXYTYPE, 0);
+		break;
+
+	default:
+	case UGET_PROXY_DEFAULT:
+	case UGET_PROXY_HTTP:
+		curl_easy_setopt (curl, CURLOPT_PROXYTYPE, CURLPROXY_HTTP);
+		break;
+
+	case UGET_PROXY_SOCKS4:
+		curl_easy_setopt (curl, CURLOPT_PROXYTYPE, CURLPROXY_SOCKS4);
+		break;
+
+	case UGET_PROXY_SOCKS5:
+		curl_easy_setopt (curl, CURLOPT_PROXYTYPE, CURLPROXY_SOCKS5);
+		break;
+	}
+
+	curl_easy_setopt (curl, CURLOPT_PROXY, proxy->host);
+	if (proxy->port)
+		curl_easy_setopt (curl, CURLOPT_PROXYPORT, proxy->port);
+	else
+		curl_easy_setopt (curl, CURLOPT_PROXYPORT, 80);
+	// proxy user and password
+	if ((proxy->user     && proxy->user[0]) ||
+		(proxy->password && proxy->password[0]) ||
+		proxy->type == UGET_PROXY_SOCKS4 ||
+		proxy->type == UGET_PROXY_SOCKS5)
+	{
+		curl_easy_setopt (curl, CURLOPT_PROXYUSERNAME,
+				(proxy->user)     ? proxy->user     : "");
+		curl_easy_setopt (curl, CURLOPT_PROXYPASSWORD,
+				(proxy->password) ? proxy->password : "");
+	}
+	else {
+		curl_easy_setopt (curl, CURLOPT_PROXYUSERNAME, NULL);
+		curl_easy_setopt (curl, CURLOPT_PROXYPASSWORD, NULL);
+	}
+}
+
 // ----------------------------------------------------------------------------
 // static functions
 
@@ -765,7 +784,7 @@ static size_t uget_curl_header_http0 (char *buffer, size_t size,
 		ug_free (buffer);
 	}
 
-	return nmemb;
+	return nmemb * size;
 }
 
 static size_t uget_curl_header_ftp0 (char *buffer, size_t size,
@@ -779,13 +798,13 @@ static size_t uget_curl_header_ftp0 (char *buffer, size_t size,
 		curl_easy_setopt (ugcurl->curl, CURLOPT_HEADERDATA, NULL);
 	}
 
-	return nmemb;
+	return nmemb * size;
 }
 
 static size_t uget_curl_output_none (char *buffer, size_t size,
                                      size_t nmemb, void* data)
 {
-	return nmemb;
+	return nmemb * size;
 }
 
 static size_t uget_curl_output_default (char *buffer, size_t size,
@@ -857,11 +876,12 @@ static int    uget_curl_progress (UgetCurl* ugcurl,
 	// to abort the transfer and return CURLE_ABORTED_BY_CALLBACK.
 	if (ugcurl->end > 0 && ugcurl->pos >= ugcurl->end) {
 		ugcurl->pos = ugcurl->end;
-		ugcurl->stopped = TRUE;
+		ugcurl->size[0] = ugcurl->pos - ugcurl->beg;
+		return 1;
 	}
-	ugcurl->size[0] = ugcurl->pos - ugcurl->beg;
 
-	if (ugcurl->stopped)
+	ugcurl->size[0] = ugcurl->pos - ugcurl->beg;
+	if (ugcurl->paused)
 		return 1;
 	return 0;
 }
@@ -870,7 +890,7 @@ static int    uget_curl_progress (UgetCurl* ugcurl,
 // PWMD
 //
 #ifdef HAVE_LIBPWMD
-static int	uget_curl_set_proxy_pwmd (UgetCurl* ugcurl, UgetProxy* proxy)
+static int  uget_curl_set_proxy_pwmd (UgetCurl* ugcurl, UgetProxy* proxy)
 {
        CURL* curl;
        struct pwmd_proxy_s pwmd;
@@ -909,9 +929,8 @@ static int	uget_curl_set_proxy_pwmd (UgetCurl* ugcurl, UgetProxy* proxy)
 
 fail:
        ug_close_pwmd(&pwmd);
-       gchar *e = ug_strdup_printf("Pwmd ERR %i: %s", rc, gpg_strerror(rc));
-       if (ugcurl->event)
-               uget_event_free (ugcurl->event);
+       ugcurl->state = UGET_CURL_ERROR;
+       gchar *e = ug_strdup_printf("Pwmd ERR %u: %s", rc, gpg_strerror(rc));
        ugcurl->event = uget_event_new_error (UGET_EVENT_ERROR_CUSTOM, e);
        fprintf(stderr, "%s\n", e);
        g_free(e);
