@@ -1,6 +1,6 @@
 /*
  *
- *   Copyright (C) 2012-2015 by C.H. Huang
+ *   Copyright (C) 2012-2016 by C.H. Huang
  *   plushuang.tw@gmail.com
  *
  *  This library is free software; you can redistribute it and/or
@@ -56,7 +56,7 @@ void  ugtk_app_init (UgtkApp* app, UgetRpc* rpc)
 	app->rpc = rpc;
 	uget_app_init ((UgetApp*) app);
 	// set application config directory for each user
-	dir = g_build_filename (g_get_user_config_dir (), UGTK_APP_DIR, NULL);
+	dir = g_build_filename (ugtk_get_config_dir (), UGTK_APP_DIR, NULL);
 	uget_app_set_config_dir ((UgetApp*) app, dir);
 	g_free (dir);
 
@@ -68,12 +68,13 @@ void  ugtk_app_init (UgtkApp* app, UgetRpc* rpc)
 		ugtk_app_add_default_category (app);
 	// clipboard
 	ugtk_clipboard_init (&app->clipboard, app->setting.clipboard.pattern);
-	// plugin initialize
+	// plug-in initialize
 	uget_plugin_set (UgetPluginCurlInfo,  UGET_PLUGIN_INIT, (void*) TRUE);
 	uget_plugin_set (UgetPluginAria2Info, UGET_PLUGIN_INIT, (void*) TRUE);
 	// apply UgtkSetting
 	ugtk_app_set_plugin_setting (app, &app->setting);
 	ugtk_app_set_window_setting (app, &app->setting);
+	ugtk_app_set_column_setting (app, &app->setting);
 	ugtk_app_set_other_setting (app, &app->setting);
 	ugtk_app_set_ui_setting (app, &app->setting);
 
@@ -81,8 +82,8 @@ void  ugtk_app_init (UgtkApp* app, UgetRpc* rpc)
 	ugtk_statusbar_set_speed (&app->statusbar, 0, 0);
 	ugtk_menubar_sync_category (&app->menubar, app, TRUE);
 
-	app->last.category_index = 0;
-	app->last.infonode = uget_node_new (NULL);
+	app->recent.category_index = 0;
+	app->recent.infonode = uget_node_new (NULL);
 	// RSS
 	uget_rss_add_builtin (app->rss_builtin, UGET_RSS_STABLE);
 	uget_rss_add_builtin (app->rss_builtin, UGET_RSS_NEWS);
@@ -114,7 +115,7 @@ void  ugtk_app_final (UgtkApp* app)
 		shutdown_now = FALSE;
 	uget_rss_unref (app->rss_builtin);
 	uget_app_final ((UgetApp*) app);
-	// plugin finalize
+	// plug-in finalize
 	uget_plugin_set (UgetPluginAria2Info, UGET_PLUGIN_ARIA2_SHUTDOWN_NOW,
 			(void*)(intptr_t) shutdown_now);
 	uget_plugin_set (UgetPluginCurlInfo,  UGET_PLUGIN_INIT, (void*) FALSE);
@@ -136,7 +137,7 @@ void  ugtk_app_save (UgtkApp* app)
 	uget_rss_save_feeds (app->rss_builtin, file);
 	g_free (file);
 
-//	uget_app_save_categories ((UgetApp*) app, g_get_user_config_dir ());
+//	uget_app_save_categories ((UgetApp*) app, ugtk_get_config_dir ());
 	uget_app_save_categories ((UgetApp*) app, NULL);
 }
 
@@ -162,7 +163,7 @@ void  ugtk_app_load (UgtkApp* app)
 	uget_rss_load_feeds (app->rss_builtin, file);
 	g_free (file);
 
-//	uget_app_load_categories ((UgetApp*) app, g_get_user_config_dir ());
+//	uget_app_load_categories ((UgetApp*) app, ugtk_get_config_dir ());
 	counts = uget_app_load_categories ((UgetApp*) app, NULL);
 	if (counts == 0)
 		ugtk_app_add_default_category (app);
@@ -174,8 +175,9 @@ void  ugtk_app_quit (UgtkApp* app)
 	uget_task_remove_all (&app->task);
 	// sync setting and save data
 	ugtk_app_get_window_setting (app, &app->setting);
+	ugtk_app_get_column_setting (app, &app->setting);
 	ugtk_app_save (app);
-	// clear plugin
+	// clear plug-in
 	uget_app_clear_plugins ((UgetApp*) app);
 	// hide icon in system tray before quit
 	ugtk_tray_icon_set_visible (&app->trayicon, FALSE);
@@ -189,7 +191,6 @@ void  ugtk_app_get_window_setting (UgtkApp* app, UgtkSetting* setting)
 {
 	GdkWindowState  gdk_wstate;
 	GdkWindow*      gdk_window;
-	GtkAllocation   allocation;
 	gint            x, y;
 
 	// get window position, size, and maximzied state
@@ -216,11 +217,8 @@ void  ugtk_app_get_window_setting (UgtkApp* app, UgtkSetting* setting)
 	// GtkPaned position
 	if (app->setting.window.category)
 		setting->window.paned_position_h = gtk_paned_get_position (app->window.hpaned);
-	if (app->setting.window.summary) {
-		gtk_widget_get_allocation ((GtkWidget*) app->window.vpaned, &allocation);
+	if (app->setting.window.summary)
 		setting->window.paned_position_v = gtk_paned_get_position (app->window.vpaned);
-		setting->window.paned_position_v = allocation.height - setting->window.paned_position_v;
-	}
 
 	// banner
 	setting->window.banner = gtk_widget_get_visible (app->banner.self);
@@ -231,8 +229,6 @@ void  ugtk_app_get_window_setting (UgtkApp* app, UgtkSetting* setting)
 
 void  ugtk_app_set_window_setting (UgtkApp* app, UgtkSetting* setting)
 {
-	GtkAllocation   allocation;
-
 	// set window position, size, and maximized state
 	if (setting->window.width  > 0 &&
 	    setting->window.height > 0 &&
@@ -254,9 +250,9 @@ void  ugtk_app_set_window_setting (UgtkApp* app, UgtkSetting* setting)
 		                        setting->window.paned_position_h);
 	}
 	if (setting->window.paned_position_v > 0) {
-		gtk_widget_get_allocation ((GtkWidget*) app->window.vpaned, &allocation);
+		if (setting->window.paned_position_v > 100) // for uGet < 2.0.4
 		gtk_paned_set_position (app->window.vpaned,
-				allocation.height - setting->window.paned_position_v);
+		                        setting->window.paned_position_v);
 	}
 	// set visible widgets
 	gtk_widget_set_visible (app->toolbar.self,
@@ -288,8 +284,188 @@ void  ugtk_app_set_window_setting (UgtkApp* app, UgtkSetting* setting)
 	ugtk_app_set_menu_setting (app, setting);
 }
 
+void  ugtk_app_get_column_setting (UgtkApp* app, UgtkSetting* setting)
+{
+	GtkTreeViewColumn* column;
+	int                width;
+
+	// name
+	column = gtk_tree_view_get_column (app->traveler.download.view,
+			UGTK_NODE_COLUMN_NAME);
+	width = gtk_tree_view_column_get_width (column);
+	setting->download_column.width.name = width;
+	// complete
+	column = gtk_tree_view_get_column (app->traveler.download.view,
+			UGTK_NODE_COLUMN_COMPLETE);
+	width = gtk_tree_view_column_get_width (column);
+	setting->download_column.width.complete = width;
+	// total
+	column = gtk_tree_view_get_column (app->traveler.download.view,
+			UGTK_NODE_COLUMN_TOTAL);
+	width = gtk_tree_view_column_get_width (column);
+	setting->download_column.width.total = width;
+	// percent
+	column = gtk_tree_view_get_column (app->traveler.download.view,
+			UGTK_NODE_COLUMN_PERCENT);
+	width = gtk_tree_view_column_get_width (column);
+	setting->download_column.width.percent = width;
+	// elapsed
+	column = gtk_tree_view_get_column (app->traveler.download.view,
+			UGTK_NODE_COLUMN_ELAPSED);
+	width = gtk_tree_view_column_get_width (column);
+	setting->download_column.width.elapsed = width;
+	// left
+	column = gtk_tree_view_get_column (app->traveler.download.view,
+			UGTK_NODE_COLUMN_LEFT);
+	width = gtk_tree_view_column_get_width (column);
+	setting->download_column.width.left = width;
+	// speed
+	column = gtk_tree_view_get_column (app->traveler.download.view,
+			UGTK_NODE_COLUMN_SPEED);
+	width = gtk_tree_view_column_get_width (column);
+	setting->download_column.width.speed = width;
+	// upload_speed
+	column = gtk_tree_view_get_column (app->traveler.download.view,
+			UGTK_NODE_COLUMN_UPLOAD_SPEED);
+	width = gtk_tree_view_column_get_width (column);
+	setting->download_column.width.upload_speed = width;
+	// uploaded
+	column = gtk_tree_view_get_column (app->traveler.download.view,
+			UGTK_NODE_COLUMN_UPLOADED);
+	width = gtk_tree_view_column_get_width (column);
+	setting->download_column.width.uploaded = width;
+	// ratio
+	column = gtk_tree_view_get_column (app->traveler.download.view,
+			UGTK_NODE_COLUMN_RATIO);
+	width = gtk_tree_view_column_get_width (column);
+	setting->download_column.width.ratio = width;
+	// retry
+	column = gtk_tree_view_get_column (app->traveler.download.view,
+			UGTK_NODE_COLUMN_RETRY);
+	width = gtk_tree_view_column_get_width (column);
+	setting->download_column.width.retry = width;
+	// category
+	column = gtk_tree_view_get_column (app->traveler.download.view,
+			UGTK_NODE_COLUMN_CATEGORY);
+	width = gtk_tree_view_column_get_width (column);
+	setting->download_column.width.category = width;
+	// uri
+	column = gtk_tree_view_get_column (app->traveler.download.view,
+			UGTK_NODE_COLUMN_URI);
+	width = gtk_tree_view_column_get_width (column);
+	setting->download_column.width.uri = width;
+	// added_on
+	column = gtk_tree_view_get_column (app->traveler.download.view,
+			UGTK_NODE_COLUMN_ADDED_ON);
+	width = gtk_tree_view_column_get_width (column);
+	setting->download_column.width.added_on = width;
+	// completed_on
+	column = gtk_tree_view_get_column (app->traveler.download.view,
+			UGTK_NODE_COLUMN_COMPLETED_ON);
+	width = gtk_tree_view_column_get_width (column);
+	setting->download_column.width.completed_on = width;
+}
+
+void  ugtk_app_set_column_setting (UgtkApp* app, UgtkSetting* setting)
+{
+	GtkTreeViewColumn* column;
+	int                width;
+
+	// name
+	column = gtk_tree_view_get_column (app->traveler.download.view,
+			UGTK_NODE_COLUMN_NAME);
+	width = setting->download_column.width.name;
+	if (width > 0)
+		gtk_tree_view_column_set_fixed_width (column, width);
+	// complete
+	column = gtk_tree_view_get_column (app->traveler.download.view,
+			UGTK_NODE_COLUMN_COMPLETE);
+	width = setting->download_column.width.complete;
+	if (width > 0)
+		gtk_tree_view_column_set_fixed_width (column, width);
+	// total
+	column = gtk_tree_view_get_column (app->traveler.download.view,
+			UGTK_NODE_COLUMN_TOTAL);
+	width = setting->download_column.width.total;
+	if (width > 0)
+		gtk_tree_view_column_set_fixed_width (column, width);
+	// percent
+	column = gtk_tree_view_get_column (app->traveler.download.view,
+			UGTK_NODE_COLUMN_PERCENT);
+	width = setting->download_column.width.percent;
+	if (width > 0)
+		gtk_tree_view_column_set_fixed_width (column, width);
+	// elapsed
+	column = gtk_tree_view_get_column (app->traveler.download.view,
+			UGTK_NODE_COLUMN_ELAPSED);
+	width = setting->download_column.width.elapsed;
+	if (width > 0)
+		gtk_tree_view_column_set_fixed_width (column, width);
+	// left
+	column = gtk_tree_view_get_column (app->traveler.download.view,
+			UGTK_NODE_COLUMN_LEFT);
+	width = setting->download_column.width.left;
+	if (width > 0)
+		gtk_tree_view_column_set_fixed_width (column, width);
+	// speed
+	column = gtk_tree_view_get_column (app->traveler.download.view,
+			UGTK_NODE_COLUMN_SPEED);
+	width = setting->download_column.width.speed;
+	if (width > 0)
+		gtk_tree_view_column_set_fixed_width (column, width);
+	// upload_speed
+	column = gtk_tree_view_get_column (app->traveler.download.view,
+			UGTK_NODE_COLUMN_UPLOAD_SPEED);
+	width = setting->download_column.width.upload_speed;
+	if (width > 0)
+		gtk_tree_view_column_set_fixed_width (column, width);
+	// uploaded
+	column = gtk_tree_view_get_column (app->traveler.download.view,
+			UGTK_NODE_COLUMN_UPLOADED);
+	width = setting->download_column.width.uploaded;
+	if (width > 0)
+		gtk_tree_view_column_set_fixed_width (column, width);
+	// ratio
+	column = gtk_tree_view_get_column (app->traveler.download.view,
+			UGTK_NODE_COLUMN_RATIO);
+	width = setting->download_column.width.ratio;
+	if (width > 0)
+		gtk_tree_view_column_set_fixed_width (column, width);
+	// retry
+	column = gtk_tree_view_get_column (app->traveler.download.view,
+			UGTK_NODE_COLUMN_RETRY);
+	width = setting->download_column.width.retry;
+	if (width > 0)
+		gtk_tree_view_column_set_fixed_width (column, width);
+	// category
+	column = gtk_tree_view_get_column (app->traveler.download.view,
+			UGTK_NODE_COLUMN_CATEGORY);
+	width = setting->download_column.width.category;
+	if (width > 0)
+		gtk_tree_view_column_set_fixed_width (column, width);
+	// uri
+	column = gtk_tree_view_get_column (app->traveler.download.view,
+			UGTK_NODE_COLUMN_URI);
+	width = setting->download_column.width.uri;
+	if (width > 0)
+		gtk_tree_view_column_set_fixed_width (column, width);
+	// added_on
+	column = gtk_tree_view_get_column (app->traveler.download.view,
+			UGTK_NODE_COLUMN_ADDED_ON);
+	width = setting->download_column.width.added_on;
+	if (width > 0)
+		gtk_tree_view_column_set_fixed_width (column, width);
+	// completed_on
+	column = gtk_tree_view_get_column (app->traveler.download.view,
+			UGTK_NODE_COLUMN_COMPLETED_ON);
+	width = setting->download_column.width.completed_on;
+	if (width > 0)
+		gtk_tree_view_column_set_fixed_width (column, width);
+}
+
 void  ugtk_app_set_plugin_setting (UgtkApp* app, UgtkSetting* setting)
 {
+	const UgetPluginInfo*  default_plugin;
 	int  limit[2];
 	int  sensitive = FALSE;
 
@@ -297,29 +473,32 @@ void  ugtk_app_set_plugin_setting (UgtkApp* app, UgtkSetting* setting)
 	default:
 	case UGTK_PLUGIN_ORDER_CURL:
 		uget_app_remove_plugin ((UgetApp*) app, UgetPluginAria2Info);
-		uget_app_set_default_plugin ((UgetApp*) app, UgetPluginCurlInfo);
+		default_plugin = UgetPluginCurlInfo;
 		sensitive = FALSE;
 		break;
 
 	case UGTK_PLUGIN_ORDER_ARIA2:
 		uget_app_remove_plugin ((UgetApp*) app, UgetPluginCurlInfo);
-		uget_app_set_default_plugin ((UgetApp*) app, UgetPluginAria2Info);
+		default_plugin = UgetPluginAria2Info;
 		sensitive = TRUE;
 		break;
 
 	case UGTK_PLUGIN_ORDER_CURL_ARIA2:
 		uget_app_add_plugin ((UgetApp*) app, UgetPluginAria2Info);
-		uget_app_set_default_plugin ((UgetApp*) app, UgetPluginCurlInfo);
+		default_plugin = UgetPluginCurlInfo;
 		sensitive = TRUE;
 		break;
 
 	case UGTK_PLUGIN_ORDER_ARIA2_CURL:
 		uget_app_add_plugin ((UgetApp*) app, UgetPluginCurlInfo);
-		uget_app_set_default_plugin ((UgetApp*) app, UgetPluginAria2Info);
+		default_plugin = UgetPluginAria2Info;
 		sensitive = TRUE;
 		break;
 	}
 
+	// set default plug-in
+	uget_app_set_default_plugin ((UgetApp*) app, default_plugin);
+	// set aria2 plug-in
 	if (setting->plugin_order >= UGTK_PLUGIN_ORDER_ARIA2) {
 		uget_plugin_set (UgetPluginAria2Info, UGET_PLUGIN_ARIA2_URI,
 		                 setting->aria2.uri);
@@ -350,8 +529,7 @@ void  ugtk_app_set_plugin_setting (UgtkApp* app, UgtkSetting* setting)
 void  ugtk_app_set_other_setting (UgtkApp* app, UgtkSetting* setting)
 {
 	// clipboard & commandline
-	ugtk_clipboard_set_pattern (&app->clipboard,
-			setting->clipboard.pattern);
+	ugtk_clipboard_set_pattern (&app->clipboard, setting->clipboard.pattern);
 	// global speed limit
 	uget_task_set_speed (&app->task,
 			setting->bandwidth.normal.download * 1024,
@@ -375,8 +553,8 @@ void  ugtk_app_set_menu_setting (UgtkApp* app, UgtkSetting* setting)
 			(GtkCheckMenuItem*) app->menubar.edit.skip_existing,
 			setting->ui.skip_existing);
 	gtk_check_menu_item_set_active (
-			(GtkCheckMenuItem*) app->menubar.edit.apply_recently,
-			setting->ui.apply_recently);
+			(GtkCheckMenuItem*) app->menubar.edit.apply_recent,
+			setting->ui.apply_recent);
 
 	switch (app->setting.completion.action) {
 	default:
@@ -445,8 +623,8 @@ void  ugtk_app_set_menu_setting (UgtkApp* app, UgtkSetting* setting)
 			setting->summary.message);
 	// download column
 	gtk_check_menu_item_set_active (
-			(GtkCheckMenuItem*) app->menubar.view.columns.completed,
-			setting->download_column.completed);
+			(GtkCheckMenuItem*) app->menubar.view.columns.complete,
+			setting->download_column.complete);
 	gtk_check_menu_item_set_active (
 			(GtkCheckMenuItem*) app->menubar.view.columns.total,
 			setting->download_column.total);
@@ -671,16 +849,20 @@ void  ugtk_app_create_category (UgtkApp* app)
 void  ugtk_app_create_download (UgtkApp* app, const char* sub_title, const char* uri)
 {
 	UgtkNodeDialog*  ndialog;
+	UgUri      uuri;
 	UgetNode*  cnode;
-	gchar*     title;
 	GList*     list;
+	union {
+		gchar*     title;
+		UgetNode*  cnode;
+	} temp;
 
 	if (sub_title)
-		title = g_strconcat (UGTK_APP_NAME, " - ", sub_title, NULL);
+		temp.title = g_strconcat (UGTK_APP_NAME, " - ", sub_title, NULL);
 	else
-		title = g_strconcat (UGTK_APP_NAME, " - ", _("New Download"), NULL);
-	ndialog = ugtk_node_dialog_new (title, app, FALSE);
-	g_free (title);
+		temp.title = g_strconcat (UGTK_APP_NAME, " - ", _("New Download"), NULL);
+	ndialog = ugtk_node_dialog_new (temp.title, app, FALSE);
+	g_free (temp.title);
 	ugtk_download_form_set_folders (&ndialog->download, &app->setting);
 
 	// category list
@@ -688,21 +870,34 @@ void  ugtk_app_create_download (UgtkApp* app, const char* sub_title, const char*
 //	cnode = cnode->data;
 	if (cnode->parent != &app->real)
 		cnode = app->real.children;
-	ugtk_node_dialog_set_category (ndialog, cnode->data);
 
-	list = NULL;
-	if (uri)
-		gtk_entry_set_text (GTK_ENTRY (ndialog->download.uri_entry), uri);
-	else
-		list = ugtk_clipboard_get_uris (&app->clipboard);
-	// use first URI from clipboard to set URL entry
-	if (list) {
+	if (uri != NULL) {
+		// set URI entry
+		gtk_entry_set_text ((GtkEntry*) ndialog->download.uri_entry, uri);
 		ndialog->download.changed.uri = TRUE;
+		// match category by URI
+		ug_uri_init (&uuri, uri);
+		temp.cnode = uget_app_match_category ((UgetApp*) app, &uuri, NULL);
+		if (temp.cnode)
+			cnode = temp.cnode;
+	}
+	else if ( (list = ugtk_clipboard_get_uris (&app->clipboard)) != NULL ) {
+		// use first URI from clipboard to set URI entry
 		gtk_entry_set_text ((GtkEntry*) ndialog->download.uri_entry, list->data);
+		ndialog->download.changed.uri = TRUE;
+		// match category by URI from clipboard
+		ug_uri_init (&uuri, list->data);
+		temp.cnode = uget_app_match_category ((UgetApp*) app, &uuri, NULL);
+		if (temp.cnode)
+			cnode = temp.cnode;
+		//
 		g_list_free_full (list, g_free);
 		ugtk_download_form_complete_entry (&ndialog->download);
 	}
 
+	if (cnode)
+		cnode = cnode->data;
+	ugtk_node_dialog_set_category (ndialog, cnode);
 	ugtk_node_dialog_run (ndialog, UGTK_NODE_DIALOG_NEW_DOWNLOAD, NULL);
 }
 
@@ -826,7 +1021,7 @@ void  ugtk_app_edit_download (UgtkApp* app)
 // ------------------------------------
 // queue/pause
 
-void  ugtk_app_queue_download (UgtkApp* app)
+void  ugtk_app_queue_download (UgtkApp* app, gboolean keep_active)
 {
 	UgetNode*  node;
 	UgetNode*  cursor;
@@ -839,6 +1034,8 @@ void  ugtk_app_queue_download (UgtkApp* app)
 		node = link->data;
 		node = node->data;
 		link->data = node;
+		if (keep_active && node->state & UGET_STATE_ACTIVE)
+			continue;
 		uget_app_queue_download ((UgetApp*) app, node);
 	}
 	if (app->traveler.state.cursor.pos == 0) {
@@ -1072,7 +1269,7 @@ void  ugtk_app_create_torrent (UgtkApp* app)
 	title = g_strconcat (UGTK_APP_NAME " - ", _("Open Torrent file"), NULL);
 	dialog = create_file_chooser (app->window.self,
 			GTK_FILE_CHOOSER_ACTION_OPEN,
-			title, "Torrent file (*.torrent)", "application/x-bittorrent");
+			title, _("Torrent file (*.torrent)"), "application/x-bittorrent");
 	g_free (title);
 	g_signal_connect (dialog, "response",
 			G_CALLBACK (on_create_torrent_response), app);
@@ -1177,7 +1374,7 @@ void  ugtk_app_load_category (UgtkApp* app)
 	title = g_strconcat (UGTK_APP_NAME " - ", _("Open Category file"), NULL);
 	dialog = create_file_chooser (app->window.self,
 			GTK_FILE_CHOOSER_ACTION_OPEN,
-			title, "JSON file (*.json)", "application/json");
+			title, _("JSON file (*.json)"), "application/json");
 	g_free (title);
 
 	g_signal_connect (dialog, "response",
@@ -1333,7 +1530,7 @@ void  ugtk_app_import_html_file (UgtkApp* app)
 	title = g_strconcat (UGTK_APP_NAME " - ", _("Import URLs from HTML file"), NULL);
 	dialog = create_file_chooser (app->window.self,
 			GTK_FILE_CHOOSER_ACTION_OPEN,
-			title, "HTML file (*.htm, *.html)", "text/html");
+			title, _("HTML file (*.htm, *.html)"), "text/html");
 	g_free (title);
 	g_signal_connect (dialog, "response",
 			G_CALLBACK (on_import_html_file_response), app);
@@ -1348,7 +1545,7 @@ void  ugtk_app_import_text_file (UgtkApp* app)
 	title = g_strconcat (UGTK_APP_NAME " - ", _("Import URLs from text file"), NULL);
 	dialog = create_file_chooser (app->window.self,
 			GTK_FILE_CHOOSER_ACTION_OPEN,
-			title, "Plain text file", "text/plain");
+			title, _("Plain text file"), "text/plain");
 	g_free (title);
 	g_signal_connect (dialog, "response",
 			G_CALLBACK (on_import_text_file_response), app);
@@ -1578,6 +1775,7 @@ void  ugtk_clipboard_init (struct UgtkClipboard* clipboard, const gchar* pattern
 	clipboard->self  = gtk_clipboard_get (GDK_SELECTION_CLIPBOARD);
 	clipboard->text  = NULL;
 	clipboard->regex = g_regex_new (pattern, G_REGEX_CASELESS, 0, NULL);
+	clipboard->media_website = TRUE;
 }
 
 void  ugtk_clipboard_set_pattern (struct UgtkClipboard* clipboard, const gchar* pattern)
