@@ -1,6 +1,6 @@
 /*
  *
- *   Copyright (C) 2012-2015 by C.H. Huang
+ *   Copyright (C) 2012-2016 by C.H. Huang
  *   plushuang.tw@gmail.com
  *
  *  This library is free software; you can redistribute it and/or
@@ -52,17 +52,21 @@ extern "C" {
 #endif
 
 #ifndef PACKAGE_VERSION
-#define PACKAGE_VERSION		"2.0.2"
+#define PACKAGE_VERSION		"2.0.7"
 #endif
 
 // ----------------------------------------------------------------------------
 // path
 
 const char* ugtk_get_data_dir (void);
+const char* ugtk_get_config_dir (void);
 const char* ugtk_get_locale_dir (void);
 
 #if defined _WIN32 || defined _WIN64
 
+const char* ugtk_get_install_dir (void);
+gboolean    ugtk_is_portable (void);
+
 #ifndef DATADIR
 #define DATADIR    ugtk_get_data_dir()
 #endif
