@@ -1,6 +1,6 @@
 /*
  *
- *   Copyright (C) 2012-2015 by C.H. Huang
+ *   Copyright (C) 2012-2016 by C.H. Huang
  *   plushuang.tw@gmail.com
  *
  *  This library is free software; you can redistribute it and/or
@@ -132,16 +132,16 @@ static void on_skip_existing (GtkWidget* widget, UgtkApp* app)
 	app->trayicon.menu.emission = TRUE;
 }
 
-static void on_apply_recently (GtkWidget* widget, UgtkApp* app)
+static void on_apply_recent (GtkWidget* widget, UgtkApp* app)
 {
 	gboolean	active;
 
 	active = gtk_check_menu_item_get_active ((GtkCheckMenuItem*) widget);
-	app->setting.ui.apply_recently = active;
+	app->setting.ui.apply_recent = active;
 
 	app->trayicon.menu.emission = FALSE;
 	gtk_check_menu_item_set_active (
-			(GtkCheckMenuItem*) app->trayicon.menu.apply_recently, active);
+			(GtkCheckMenuItem*) app->trayicon.menu.apply_recent, active);
 	app->trayicon.menu.emission = TRUE;
 }
 
@@ -276,12 +276,12 @@ static void  on_change_visible_column (GtkWidget* widget, UgtkApp* app)
 	traveler = &app->traveler;
 	visible  = gtk_check_menu_item_get_active ((GtkCheckMenuItem*) widget);
 	// which widget
-	if (widget == app->menubar.view.columns.completed) {
+	if (widget == app->menubar.view.columns.complete) {
 		column_index = UGTK_NODE_COLUMN_COMPLETE;
-		setting->completed = visible;
+		setting->complete = visible;
 	}
 	else if (widget == app->menubar.view.columns.total) {
-		column_index = UGTK_NODE_COLUMN_SIZE;
+		column_index = UGTK_NODE_COLUMN_TOTAL;
 		setting->total = visible;
 	}
 	else if (widget == app->menubar.view.columns.percent) {
@@ -572,6 +572,11 @@ static void on_set_download_force_start (GtkWidget* widget, UgtkApp* app)
 //	ugtk_summary_show (&app->summary, app->traveler.download.cursor.node);
 }
 
+static void on_set_download_runnable (GtkWidget* widget, UgtkApp* app)
+{
+	ugtk_app_queue_download (app, TRUE);
+}
+
 // UgtkMenubar.download.move_to
 static void on_move_download (GtkWidget* widget, UgtkApp* app)
 {
@@ -734,8 +739,8 @@ void ugtk_menubar_init_callback (UgtkMenubar* menubar, UgtkApp* app)
 			G_CALLBACK (on_commandline_quiet), app);
 	g_signal_connect (menubar->edit.skip_existing, "activate",
 			G_CALLBACK (on_skip_existing), app);
-	g_signal_connect (menubar->edit.apply_recently, "activate",
-			G_CALLBACK (on_apply_recently), app);
+	g_signal_connect (menubar->edit.apply_recent, "activate",
+			G_CALLBACK (on_apply_recent), app);
 
 	g_signal_connect (menubar->edit.completion.disable, "activate",
 			G_CALLBACK (on_config_completion), app);
@@ -778,7 +783,7 @@ void ugtk_menubar_init_callback (UgtkMenubar* menubar, UgtkApp* app)
 	g_signal_connect (menubar->view.summary_items.message, "toggled",
 			G_CALLBACK (on_change_visible_summary), app);
 	// download columns
-	g_signal_connect (menubar->view.columns.completed, "toggled",
+	g_signal_connect (menubar->view.columns.complete, "toggled",
 			G_CALLBACK (on_change_visible_column), app);
 	g_signal_connect (menubar->view.columns.total, "toggled",
 			G_CALLBACK (on_change_visible_column), app);
@@ -836,8 +841,8 @@ void ugtk_menubar_init_callback (UgtkMenubar* menubar, UgtkApp* app)
 	// change status
 	g_signal_connect (menubar->download.force_start, "activate",
 			G_CALLBACK (on_set_download_force_start), app);
-	g_signal_connect_swapped (menubar->download.runnable, "activate",
-			G_CALLBACK (ugtk_app_queue_download), app);
+	g_signal_connect (menubar->download.runnable, "activate",
+			G_CALLBACK (on_set_download_runnable), app);
 	g_signal_connect_swapped (menubar->download.pause, "activate",
 			G_CALLBACK (ugtk_app_pause_download), app);
 	// move
