@@ -1,6 +1,6 @@
 /*
  *
- *   Copyright (C) 2012-2015 by C.H. Huang
+ *   Copyright (C) 2012-2016 by C.H. Huang
  *   plushuang.tw@gmail.com
  *
  *  This library is free software; you can redistribute it and/or
@@ -37,6 +37,7 @@
 #include <UgStdio.h>
 #include <UgString.h>
 #include <UgJsonFile.h>
+#include <UgetMedia.h>
 #include <UgtkSetting.h>
 #include <UgtkNodeView.h>
 
@@ -111,9 +112,44 @@ static const UgEntry  UgtkSummarySettingEntry[] =
 // ----------------------------------------------------------------------------
 // DownloadColumnSetting
 
+static const UgEntry  UgtkDownloadColumnWidthEntry[] =
+{
+	{"name",        offsetof (struct UgtkDownloadColumnWidth, name),
+			UG_ENTRY_INT,  NULL,  NULL},
+	{"complete",    offsetof (struct UgtkDownloadColumnWidth, complete),
+			UG_ENTRY_INT,  NULL,  NULL},
+	{"total",       offsetof (struct UgtkDownloadColumnWidth, total),
+			UG_ENTRY_INT,  NULL,  NULL},
+	{"percent",     offsetof (struct UgtkDownloadColumnWidth, percent),
+			UG_ENTRY_INT,  NULL,  NULL},
+	{"elapsed",     offsetof (struct UgtkDownloadColumnWidth, elapsed),
+			UG_ENTRY_INT,  NULL,  NULL},
+	{"left",        offsetof (struct UgtkDownloadColumnWidth, left),
+			UG_ENTRY_INT,  NULL,  NULL},
+	{"speed",       offsetof (struct UgtkDownloadColumnWidth, speed),
+			UG_ENTRY_INT,  NULL,  NULL},
+	{"UploadSpeed", offsetof (struct UgtkDownloadColumnWidth, upload_speed),
+			UG_ENTRY_INT,  NULL,  NULL},
+	{"uploaded",    offsetof (struct UgtkDownloadColumnWidth, uploaded),
+			UG_ENTRY_INT,  NULL,  NULL},
+	{"ratio",       offsetof (struct UgtkDownloadColumnWidth, ratio),
+			UG_ENTRY_INT,  NULL,  NULL},
+	{"retry",       offsetof (struct UgtkDownloadColumnWidth, retry),
+			UG_ENTRY_INT,  NULL,  NULL},
+	{"category",    offsetof (struct UgtkDownloadColumnWidth, category),
+			UG_ENTRY_INT,  NULL,  NULL},
+	{"uri",         offsetof (struct UgtkDownloadColumnWidth, uri),
+			UG_ENTRY_INT,  NULL,  NULL},
+	{"AddedOn",     offsetof (struct UgtkDownloadColumnWidth, added_on),
+			UG_ENTRY_INT,  NULL,  NULL},
+	{"CompletedOn", offsetof (struct UgtkDownloadColumnWidth, completed_on),
+			UG_ENTRY_INT,  NULL,  NULL},
+	{NULL}    // null-terminated
+};
+
 static const UgEntry  UgtkDownloadColumnSettingEntry[] =
 {
-	{"completed",   offsetof (struct UgtkDownloadColumnSetting, completed),
+	{"complete",    offsetof (struct UgtkDownloadColumnSetting, complete),
 			UG_ENTRY_BOOL,  NULL,  NULL},
 	{"total",       offsetof (struct UgtkDownloadColumnSetting, total),
 			UG_ENTRY_BOOL,  NULL,  NULL},
@@ -146,6 +182,14 @@ static const UgEntry  UgtkDownloadColumnSettingEntry[] =
 			UG_ENTRY_INT,  NULL,  NULL},
 	{"SortNth",     offsetof (struct UgtkDownloadColumnSetting, sort.nth),
 			UG_ENTRY_INT,  NULL,  NULL},
+
+	{"Width",       offsetof (struct UgtkDownloadColumnSetting, width),
+			UG_ENTRY_OBJECT, (void*) UgtkDownloadColumnWidthEntry, NULL},
+
+	// deprecated
+	{"completed",   offsetof (struct UgtkDownloadColumnSetting, complete),
+			UG_ENTRY_BOOL,  NULL,  NULL},
+
 	{NULL}    // null-terminated
 };
 
@@ -170,7 +214,9 @@ static const UgEntry  UgtkUserInterfaceSettingEntry[] =
 			UG_ENTRY_BOOL,  NULL,  NULL},
 	{"SoundNotification",  offsetof (struct UgtkUserInterfaceSetting, sound_notification),
 			UG_ENTRY_BOOL,  NULL,  NULL},
-	{"ApplyRecently",      offsetof (struct UgtkUserInterfaceSetting, apply_recently),
+	{"ApplyRecently",      offsetof (struct UgtkUserInterfaceSetting, apply_recent),
+			UG_ENTRY_BOOL,  NULL,  NULL},
+	{"ApplyRecent",        offsetof (struct UgtkUserInterfaceSetting, apply_recent),
 			UG_ENTRY_BOOL,  NULL,  NULL},
 	{"SkipExisting",       offsetof (struct UgtkUserInterfaceSetting, skip_existing),
 			UG_ENTRY_BOOL,  NULL,  NULL},
@@ -186,13 +232,13 @@ static const UgEntry  UgtkUserInterfaceSettingEntry[] =
 
 static const UgEntry  UgtkClipboardSettingEntry[] =
 {
-	{"pattern",     offsetof (struct UgtkClipboardSetting, pattern),
+	{"pattern",      offsetof (struct UgtkClipboardSetting, pattern),
 			UG_ENTRY_STRING, NULL,  NULL},
-	{"monitor",     offsetof (struct UgtkClipboardSetting, monitor),
+	{"monitor",      offsetof (struct UgtkClipboardSetting, monitor),
 			UG_ENTRY_BOOL,   NULL,  NULL},
-	{"quiet",       offsetof (struct UgtkClipboardSetting, quiet),
+	{"quiet",        offsetof (struct UgtkClipboardSetting, quiet),
 			UG_ENTRY_BOOL,   NULL,  NULL},
-	{"NthCategory", offsetof (struct UgtkClipboardSetting, nth_category),
+	{"NthCategory",  offsetof (struct UgtkClipboardSetting, nth_category),
 			UG_ENTRY_INT,    NULL,  NULL},
 	{NULL},    // null-terminated
 };
@@ -230,9 +276,9 @@ static const UgEntry  UgtkSchedulerSettingEntry[] =
 
 static const UgEntry  UgtkCommandlineSettingEntry[] =
 {
-	{"quiet",       offsetof (struct UgtkCommandlineSetting, quiet),
+	{"quiet",         offsetof (struct UgtkCommandlineSetting, quiet),
 			UG_ENTRY_BOOL, NULL, NULL},
-	{"NthCategory", offsetof (struct UgtkCommandlineSetting, nth_category),
+	{"NthCategory",   offsetof (struct UgtkCommandlineSetting, nth_category),
 			UG_ENTRY_INT,  NULL, NULL},
 	{NULL},    // null-terminated
 };
@@ -286,7 +332,7 @@ static const UgEntry  UgtkSettingEntry[] =
 			UG_ENTRY_OBJECT, (void*) UgtkWindowSettingEntry,  NULL},
 	{"Summary",         offsetof (UgtkSetting, summary),
 			UG_ENTRY_OBJECT, (void*) UgtkSummarySettingEntry, NULL},
-	{"DownloadColumn",	offsetof (UgtkSetting, download_column),
+	{"DownloadColumn",  offsetof (UgtkSetting, download_column),
 			UG_ENTRY_OBJECT, (void*) UgtkDownloadColumnSettingEntry, NULL},
 	{"UserInterface",   offsetof (UgtkSetting, ui),
 			UG_ENTRY_OBJECT, (void*) UgtkUserInterfaceSettingEntry,  NULL},
@@ -308,7 +354,7 @@ static const UgEntry  UgtkSettingEntry[] =
 	{"FolderHistory",   offsetof (UgtkSetting, folder_history),
 			UG_ENTRY_ARRAY, ug_json_parse_list_string,  ug_json_write_list_string},
 
-	{"AutoSave",		offsetof (UgtkSetting, auto_save.enable),
+	{"AutoSave",        offsetof (UgtkSetting, auto_save.enable),
 			UG_ENTRY_INT,    NULL,  NULL},
 	{"AutoSaveInterval",offsetof (UgtkSetting, auto_save.interval),
 			UG_ENTRY_INT,    NULL,  NULL},
@@ -325,6 +371,7 @@ static const UgEntry  UgtkSettingEntry[] =
 //
 void  ugtk_setting_init (UgtkSetting* setting)
 {
+	// "SchedulerSetting"
 	ug_array_init (&setting->scheduler.state, sizeof (int), 7*24);
 	memset (setting->scheduler.state.at, UGTK_SCHEDULE_NORMAL, 7*24);
 }
@@ -355,7 +402,7 @@ void  ugtk_setting_reset (UgtkSetting* setting)
 	setting->summary.message  = TRUE;
 
 	// "DownloadColumnSetting"
-	setting->download_column.completed    = TRUE;
+	setting->download_column.complete     = TRUE;
 	setting->download_column.total        = TRUE;
 	setting->download_column.percent      = TRUE;
 	setting->download_column.elapsed      = TRUE;
@@ -372,6 +419,9 @@ void  ugtk_setting_reset (UgtkSetting* setting)
 	// default sorted column
 	setting->download_column.sort.type    = GTK_SORT_DESCENDING;
 	setting->download_column.sort.nth     = UGTK_NODE_COLUMN_ADDED_ON;
+	// "DownloadColumnWidth"
+	memset (&setting->download_column.width, 0,
+			sizeof (setting->download_column.width));
 
 	// "UserInterfaceSetting"
 	setting->ui.exit_confirmation = TRUE;
@@ -382,7 +432,7 @@ void  ugtk_setting_reset (UgtkSetting* setting)
 	setting->ui.start_in_offline_mode = FALSE;
 	setting->ui.start_notification = TRUE;
 	setting->ui.sound_notification = TRUE;
-	setting->ui.apply_recently = TRUE;
+	setting->ui.apply_recent = TRUE;
 	setting->ui.skip_existing = FALSE;
 #ifdef HAVE_APP_INDICATOR
 	setting->ui.app_indicator = TRUE;
@@ -418,7 +468,7 @@ void  ugtk_setting_reset (UgtkSetting* setting)
 
 	// "PluginSetting"
 	setting->plugin_order = UGTK_PLUGIN_ORDER_CURL;
-	// aria2 plugin settings
+	// aria2 plug-in settings
 	setting->aria2.limit.download = 0;
 	setting->aria2.limit.upload = 0;
 	setting->aria2.launch = TRUE;
@@ -579,7 +629,7 @@ void  ugtk_setting_fix_data (UgtkSetting* setting)
 	{
 		setting->plugin_order = UGTK_PLUGIN_ORDER_CURL;
 	}
-	// aria2 plugin settings
+	// aria2 plug-in settings
 	if (setting->aria2.path == NULL || setting->aria2.path[0] == 0) {
 		ug_free (setting->aria2.path);
 		setting->aria2.path = ug_strdup (UGTK_ARIA2_PATH);
