@@ -1,6 +1,6 @@
 /*
  *
- *   Copyright (C) 2005-2015 by C.H. Huang
+ *   Copyright (C) 2005-2016 by C.H. Huang
  *   plushuang.tw@gmail.com
  *
  *  This library is free software; you can redistribute it and/or
@@ -35,44 +35,47 @@
  */
 
 #include <UgString.h>
+#include <UgetMedia.h>
 #include <UgtkSettingForm.h>
 
 #include <glib/gi18n.h>
 
-static void remove_line_breaks (gchar* buffer, gint len);
-
 // ----------------------------------------------------------------------------
 // UgtkClipboardForm
 //
-void  ugtk_clipboard_form_init (struct UgtkClipboardForm* csform)
+//
+void  ugtk_clipboard_form_init (struct UgtkClipboardForm* cbform)
 {
+	PangoContext*  context;
+	PangoLayout*   layout;
+	int            text_height;
 	GtkTextView* textview;
 	GtkWidget*   widget;
 	GtkBox*      vbox;
 	GtkBox*      hbox;
 	GtkScrolledWindow*  scroll;
 
-	csform->self = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
-	vbox = (GtkBox*) csform->self;
+	cbform->self = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
+	vbox = (GtkBox*) cbform->self;
 	// Monitor button
 	widget = gtk_check_button_new_with_mnemonic (_("_Enable clipboard monitor"));
 	gtk_box_pack_start (vbox, widget, FALSE, FALSE, 1);
-	csform->monitor = (GtkToggleButton*) widget;
+	cbform->monitor = (GtkToggleButton*) widget;
 
 	// quiet mode
 	widget = gtk_check_button_new_with_mnemonic (_("_Quiet mode"));
 	gtk_box_pack_start (vbox, widget, FALSE, FALSE, 0);
-	csform->quiet = (GtkToggleButton*) widget;
+	cbform->quiet = (GtkToggleButton*) widget;
 	// Nth category
 	hbox = (GtkBox*) gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 2);
 	gtk_box_pack_start (vbox, (GtkWidget*) hbox, FALSE, FALSE, 2);
 	widget = gtk_label_new (_("Default category index"));
 	gtk_box_pack_start (hbox, widget, FALSE, FALSE, 2);
-	csform->nth_label = widget;
+	cbform->nth_label = widget;
 	widget = gtk_spin_button_new_with_range (0.0, 1000.0, 1.0);
 	gtk_entry_set_activates_default (GTK_ENTRY (widget), TRUE);
 	gtk_box_pack_start (hbox, widget, FALSE, FALSE, 2);
-	csform->nth_spin = (GtkSpinButton*) widget;
+	cbform->nth_spin = (GtkSpinButton*) widget;
 	// hint
 	hbox = (GtkBox*) gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 2);
 	gtk_box_pack_start (vbox, (GtkWidget*) hbox, FALSE, FALSE, 2);
@@ -83,6 +86,13 @@ void  ugtk_clipboard_form_init (struct UgtkClipboardForm* csform)
 
 	gtk_box_pack_start (vbox, gtk_label_new (""), FALSE, FALSE, 2);
 
+	// get text height --- begin ---
+	context = gtk_widget_get_pango_context (widget);
+	layout = pango_layout_new (context);
+	pango_layout_set_text (layout, "joIN", -1);
+	pango_layout_get_pixel_size (layout, NULL, &text_height);
+	g_object_unref (layout);
+	//  get text height --- end ---
 	hbox = (GtkBox*) gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 2);
 	gtk_box_pack_start (vbox, (GtkWidget*) hbox, FALSE, FALSE, 2);
 	widget = gtk_label_new (_("Monitor clipboard for specified file types:"));
@@ -90,16 +100,16 @@ void  ugtk_clipboard_form_init (struct UgtkClipboardForm* csform)
 	// Scrolled Window
 	scroll = (GtkScrolledWindow*) gtk_scrolled_window_new (NULL, NULL);
 	gtk_scrolled_window_set_shadow_type (scroll, GTK_SHADOW_IN);
-	gtk_widget_set_size_request (GTK_WIDGET (scroll), 100, 100);
+	gtk_widget_set_size_request (GTK_WIDGET (scroll), 100, text_height * 6);
 	gtk_box_pack_start (vbox, GTK_WIDGET (scroll), FALSE, FALSE, 2);
 	// file type pattern : TextView
-	csform->buffer = gtk_text_buffer_new (NULL);
-	csform->pattern = gtk_text_view_new_with_buffer (csform->buffer);
-	g_object_unref (csform->buffer);
-	textview = (GtkTextView*) csform->pattern;
+	cbform->buffer = gtk_text_buffer_new (NULL);
+	cbform->pattern = gtk_text_view_new_with_buffer (cbform->buffer);
+	g_object_unref (cbform->buffer);
+	textview = (GtkTextView*) cbform->pattern;
 	gtk_text_view_set_wrap_mode (textview, GTK_WRAP_WORD_CHAR);
 	gtk_container_add (GTK_CONTAINER (scroll),
-			GTK_WIDGET (csform->pattern));
+			GTK_WIDGET (cbform->pattern));
 
 	// tips
 	hbox = (GtkBox*) gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 2);
@@ -114,33 +124,33 @@ void  ugtk_clipboard_form_init (struct UgtkClipboardForm* csform)
 			FALSE, FALSE, 2);
 }
 
-void  ugtk_clipboard_form_set (struct UgtkClipboardForm* csform, UgtkSetting* setting)
+void  ugtk_clipboard_form_set (struct UgtkClipboardForm* cbform, UgtkSetting* setting)
 {
 	if (setting->clipboard.pattern)
-		gtk_text_buffer_set_text (csform->buffer, setting->clipboard.pattern, -1);
-	gtk_toggle_button_set_active (csform->monitor, setting->clipboard.monitor);
-	gtk_toggle_button_set_active (csform->quiet, setting->clipboard.quiet);
-	gtk_spin_button_set_value (csform->nth_spin, setting->clipboard.nth_category);
-	gtk_toggle_button_toggled (csform->monitor);
-	gtk_toggle_button_toggled (csform->quiet);
-//	on_clipboard_quiet_mode_toggled ((GtkWidget*) csform->quiet, csform);
+		gtk_text_buffer_set_text (cbform->buffer, setting->clipboard.pattern, -1);
+	gtk_toggle_button_set_active (cbform->monitor, setting->clipboard.monitor);
+	gtk_toggle_button_set_active (cbform->quiet, setting->clipboard.quiet);
+	gtk_spin_button_set_value (cbform->nth_spin, setting->clipboard.nth_category);
+	gtk_toggle_button_toggled (cbform->monitor);
+	gtk_toggle_button_toggled (cbform->quiet);
+//	on_clipboard_quiet_mode_toggled ((GtkWidget*) cbform->quiet, cbform);
 }
 
-void  ugtk_clipboard_form_get (struct UgtkClipboardForm* csform, UgtkSetting* setting)
+void  ugtk_clipboard_form_get (struct UgtkClipboardForm* cbform, UgtkSetting* setting)
 {
 	GtkTextIter  iter1;
 	GtkTextIter  iter2;
 
-	gtk_text_buffer_get_start_iter (csform->buffer, &iter1);
-	gtk_text_buffer_get_end_iter (csform->buffer, &iter2);
+	gtk_text_buffer_get_start_iter (cbform->buffer, &iter1);
+	gtk_text_buffer_get_end_iter (cbform->buffer, &iter2);
 
 	ug_free (setting->clipboard.pattern);
-	setting->clipboard.pattern = gtk_text_buffer_get_text (csform->buffer, &iter1, &iter2, FALSE);
-	setting->clipboard.monitor = gtk_toggle_button_get_active (csform->monitor);
-	setting->clipboard.quiet = gtk_toggle_button_get_active (csform->quiet);
-	setting->clipboard.nth_category = gtk_spin_button_get_value_as_int (csform->nth_spin);
+	setting->clipboard.pattern = gtk_text_buffer_get_text (cbform->buffer, &iter1, &iter2, FALSE);
+	setting->clipboard.monitor = gtk_toggle_button_get_active (cbform->monitor);
+	setting->clipboard.quiet = gtk_toggle_button_get_active (cbform->quiet);
+	setting->clipboard.nth_category = gtk_spin_button_get_value_as_int (cbform->nth_spin);
 	// remove line break
-	remove_line_breaks (setting->clipboard.pattern, -1);
+	ug_str_remove_crlf (setting->clipboard.pattern, setting->clipboard.pattern);
 }
 
 // ----------------------------------------------------------------------------
@@ -201,8 +211,8 @@ void  ugtk_user_interface_form_init (struct UgtkUserInterfaceForm* uiform)
 	widget = gtk_check_button_new_with_label (_("Sound when download is finished"));
 	uiform->sound_notification = (GtkToggleButton*) widget;
 	gtk_box_pack_start (vbox, widget, FALSE, FALSE, 1);
-	widget = gtk_check_button_new_with_label (_("Apply recently download settings"));
-	uiform->apply_recently = (GtkToggleButton*) widget;
+	widget = gtk_check_button_new_with_label (_("Apply recent download settings"));
+	uiform->apply_recent = (GtkToggleButton*) widget;
 	gtk_box_pack_start (vbox, widget, FALSE, FALSE, 1);
 //	widget = gtk_check_button_new_with_label (_("Skip existing URI from clipboard and command-line"));
 //	uiform->skip_existing = (GtkToggleButton*) widget;
@@ -227,8 +237,8 @@ void  ugtk_user_interface_form_set (struct UgtkUserInterfaceForm* uiform, UgtkSe
 			setting->ui.start_notification);
 	gtk_toggle_button_set_active (uiform->sound_notification,
 			setting->ui.sound_notification);
-	gtk_toggle_button_set_active (uiform->apply_recently,
-			setting->ui.apply_recently);
+	gtk_toggle_button_set_active (uiform->apply_recent,
+			setting->ui.apply_recent);
 //	gtk_toggle_button_set_active (uiform->skip_existing,
 //			setting->ui.skip_existing);
 #ifdef HAVE_APP_INDICATOR
@@ -247,7 +257,7 @@ void  ugtk_user_interface_form_get (struct UgtkUserInterfaceForm* uiform, UgtkSe
 	setting->ui.start_in_offline_mode = gtk_toggle_button_get_active (uiform->start_in_offline_mode);
 	setting->ui.start_notification = gtk_toggle_button_get_active (uiform->start_notification);
 	setting->ui.sound_notification = gtk_toggle_button_get_active (uiform->sound_notification);
-	setting->ui.apply_recently = gtk_toggle_button_get_active (uiform->apply_recently);
+	setting->ui.apply_recent = gtk_toggle_button_get_active (uiform->apply_recent);
 //	setting->ui.skip_existing = gtk_toggle_button_get_active (uiform->skip_existing);
 #ifdef HAVE_APP_INDICATOR
 	setting->ui.app_indicator = gtk_toggle_button_get_active (uiform->app_indicator);
@@ -401,20 +411,26 @@ void  ugtk_auto_save_form_init (struct UgtkAutoSaveForm* asform)
 	g_signal_connect (widget, "toggled",
 			G_CALLBACK (on_auto_save_toggled), asform);
 	asform->enable = (GtkToggleButton*) widget;
-	// auto save spin & label (interval)
-	widget = gtk_label_new_with_mnemonic (_("minutes"));
-	gtk_box_pack_end (hbox, widget, FALSE, FALSE, 2);
-	asform->minutes_label = widget;
-	widget = gtk_spin_button_new_with_range (1.0, 120.0, 1.0);
-	gtk_entry_set_activates_default (GTK_ENTRY (widget), TRUE);
-	gtk_box_pack_end (hbox, widget, FALSE, FALSE, 2);
-	asform->interval_spin = (GtkSpinButton*) widget;
-	// auto save label
+
+	// space
+	widget = gtk_label_new ("");
+	gtk_box_pack_start (hbox, widget, FALSE, FALSE, 30);
+
+	// auto save interval label
 	widget = gtk_label_new_with_mnemonic (_("_Interval:"));
-	gtk_box_pack_end (hbox, widget, FALSE, FALSE, 2);
+	gtk_box_pack_start (hbox, widget, FALSE, FALSE, 2);
 	asform->interval_label = widget;
 	gtk_label_set_mnemonic_widget (GTK_LABEL (asform->interval_label),
 			(GtkWidget*) asform->interval_spin);
+	// auto save interval spin
+	widget = gtk_spin_button_new_with_range (1.0, 120.0, 1.0);
+	gtk_entry_set_activates_default (GTK_ENTRY (widget), TRUE);
+	gtk_box_pack_start (hbox, widget, FALSE, FALSE, 2);
+	asform->interval_spin = (GtkSpinButton*) widget;
+	// auto save interval unit label
+	widget = gtk_label_new_with_mnemonic (_("minutes"));
+	gtk_box_pack_start (hbox, widget, FALSE, FALSE, 2);
+	asform->minutes_label = widget;
 }
 
 void  ugtk_auto_save_form_set (struct UgtkAutoSaveForm* asform, UgtkSetting* setting)
@@ -434,7 +450,7 @@ void  ugtk_auto_save_form_get (struct UgtkAutoSaveForm* asform, UgtkSetting* set
 // ----------------------------------------------------------------------------
 // UgtkCommandlineForm
 //
-void  ugtk_commandline_form_init (struct UgtkCommandlineForm* csform)
+void  ugtk_commandline_form_init (struct UgtkCommandlineForm* clform)
 {
 	GtkWidget*  widget;
 	GtkBox*     vbox;
@@ -442,25 +458,25 @@ void  ugtk_commandline_form_init (struct UgtkCommandlineForm* csform)
 
 	// Commandline Settings
 	widget = gtk_frame_new (_("Commandline Settings"));
-	csform->self = widget;
+	clform->self = widget;
 	vbox = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
 	gtk_container_add (GTK_CONTAINER (widget), (GtkWidget*) vbox);
 	gtk_container_set_border_width (GTK_CONTAINER (vbox), 2);
 
 	// --quiet
 	widget = gtk_check_button_new_with_mnemonic (_("Use '--quiet' by default"));
-	gtk_box_pack_start (vbox, widget, FALSE, FALSE, 0);
-	csform->quiet = (GtkToggleButton*) widget;
+	gtk_box_pack_start (vbox, widget, FALSE, FALSE, 1);
+	clform->quiet = (GtkToggleButton*) widget;
 	// --category-index
 	hbox = (GtkBox*) gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 2);
 	gtk_box_pack_start (vbox, (GtkWidget*) hbox, FALSE, FALSE, 2);
 	widget = gtk_label_new (_("Default category index"));
 	gtk_box_pack_start (hbox, widget, FALSE, FALSE, 2);
-	csform->index_label = widget;
+	clform->index_label = widget;
 	widget = gtk_spin_button_new_with_range (0.0, 1000.0, 1.0);
 	gtk_entry_set_activates_default (GTK_ENTRY (widget), TRUE);
 	gtk_box_pack_start (hbox, widget, FALSE, FALSE, 2);
-	csform->index_spin = (GtkSpinButton*) widget;
+	clform->index_spin = (GtkSpinButton*) widget;
 	// hint
 	hbox = (GtkBox*) gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 2);
 	gtk_box_pack_start (vbox, (GtkWidget*) hbox, FALSE, FALSE, 2);
@@ -470,22 +486,22 @@ void  ugtk_commandline_form_init (struct UgtkCommandlineForm* csform)
 	gtk_box_pack_start (hbox, widget, FALSE, FALSE, 0);
 }
 
-void  ugtk_commandline_form_set (struct UgtkCommandlineForm* csform, UgtkSetting* setting)
+void  ugtk_commandline_form_set (struct UgtkCommandlineForm* clform, UgtkSetting* setting)
 {
-	gtk_toggle_button_set_active (csform->quiet, setting->commandline.quiet);
-	gtk_spin_button_set_value (csform->index_spin, setting->commandline.nth_category);
+	gtk_toggle_button_set_active (clform->quiet, setting->commandline.quiet);
+	gtk_spin_button_set_value (clform->index_spin, setting->commandline.nth_category);
 }
 
-void  ugtk_commandline_form_get (struct UgtkCommandlineForm* csform, UgtkSetting* setting)
+void  ugtk_commandline_form_get (struct UgtkCommandlineForm* clform, UgtkSetting* setting)
 {
-	setting->commandline.quiet = gtk_toggle_button_get_active (csform->quiet);
-	setting->commandline.nth_category = gtk_spin_button_get_value_as_int (csform->index_spin);
+	setting->commandline.quiet = gtk_toggle_button_get_active (clform->quiet);
+	setting->commandline.nth_category = gtk_spin_button_get_value_as_int (clform->index_spin);
 }
 
 // ----------------------------------------------------------------------------
 // UgtkPluginForm
 //
-static void	on_plugin_launch_toggled (GtkWidget* widget, struct UgtkPluginForm* psform)
+static void on_plugin_launch_toggled (GtkWidget* widget, struct UgtkPluginForm* psform)
 {
 	gboolean  sensitive;
 
@@ -506,6 +522,9 @@ static void on_order_changed (GtkComboBox* widget, struct UgtkPluginForm* psform
 
 void  ugtk_plugin_form_init (struct UgtkPluginForm* psform)
 {
+	PangoContext*  context;
+	PangoLayout*   layout;
+	int            text_height;
 	GtkBox*      vbox;
 	GtkBox*      hbox;
 	GtkBox*      box;
@@ -539,7 +558,7 @@ void  ugtk_plugin_form_init (struct UgtkPluginForm* psform)
 	vbox = (GtkBox*) widget;
 
 	hbox = (GtkBox*) gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
-	gtk_box_pack_start (vbox, (GtkWidget*) hbox, FALSE, TRUE, 2);
+	gtk_box_pack_start (vbox, (GtkWidget*) hbox, FALSE, TRUE, 4);
 	widget = gtk_label_new (_("Aria2 plug-in options"));
 	gtk_box_pack_start (hbox, widget, FALSE, FALSE, 0);
 	gtk_box_pack_start (hbox, gtk_separator_new (GTK_ORIENTATION_HORIZONTAL), TRUE, TRUE, 4);
@@ -628,6 +647,13 @@ void  ugtk_plugin_form_init (struct UgtkPluginForm* psform)
 	//
 	gtk_box_pack_start (box, gtk_label_new (""), FALSE, FALSE, 0);
 	// Arguments
+	// get text height --- begin ---
+	context = gtk_widget_get_pango_context (widget);
+	layout = pango_layout_new (context);
+	pango_layout_set_text (layout, "joIN", -1);
+	pango_layout_get_pixel_size (layout, NULL, &text_height);
+	g_object_unref (layout);
+	//  get text height --- end ---
 	hbox = (GtkBox*) gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
 	gtk_box_pack_start (box, (GtkWidget*) hbox, FALSE, TRUE, 2);
 	widget = gtk_label_new (_("Arguments"));
@@ -640,13 +666,13 @@ void  ugtk_plugin_form_init (struct UgtkPluginForm* psform)
 	// Arguments - Scrolled Window
 	scroll = (GtkScrolledWindow*) gtk_scrolled_window_new (NULL, NULL);
 	gtk_scrolled_window_set_shadow_type (scroll, GTK_SHADOW_IN);
-	gtk_widget_set_size_request (GTK_WIDGET (scroll), 100, 50);
+	gtk_widget_set_size_request (GTK_WIDGET (scroll), 100, text_height * 3);
 	gtk_box_pack_start (box, GTK_WIDGET (scroll), FALSE, TRUE, 2);
 	// Arguments - text view
 	psform->args_buffer = gtk_text_buffer_new (NULL);
 	psform->args = gtk_text_view_new_with_buffer (psform->args_buffer);
 	g_object_unref (psform->args_buffer);
-	gtk_text_view_set_wrap_mode ((GtkTextView*) psform->args, GTK_WRAP_WORD_CHAR);
+	gtk_text_view_set_wrap_mode ((GtkTextView*) psform->args, GTK_WRAP_CHAR);
 	gtk_container_add (GTK_CONTAINER (scroll), GTK_WIDGET (psform->args));
 
 	// ------------------------------------------------------------------------
@@ -702,25 +728,8 @@ void  ugtk_plugin_form_get (struct UgtkPluginForm* psform, UgtkSetting* setting)
 	gtk_text_buffer_get_start_iter (psform->args_buffer, &iter1);
 	gtk_text_buffer_get_end_iter (psform->args_buffer, &iter2);
 	setting->aria2.args = gtk_text_buffer_get_text (psform->args_buffer, &iter1, &iter2, FALSE);
-	remove_line_breaks (setting->aria2.args, -1);
+	ug_str_remove_crlf (setting->aria2.args, setting->aria2.args);
 
 	setting->aria2.limit.upload   = (guint) gtk_spin_button_get_value (psform->upload);
 	setting->aria2.limit.download = (guint) gtk_spin_button_get_value (psform->download);
 }
-
-// ----------------------------------------------------------------------------
-
-static void remove_line_breaks (gchar* buffer, gint len)
-{
-	gchar*  cur;
-	gchar*  end;
-
-	if (len == -1)
-		len = strlen (buffer);
-	cur = buffer;
-	end = buffer + len;
-	while ( (cur = strchr (cur, '\n')) ) {
-		memmove (cur, cur + 1, end - cur);
-		end--;
-	}
-}
